nxp-pac

Crates

git

Versions

mcxn947_cm33_core0

Flavors

TrimOverrideEn

Struct TrimOverrideEn 

#[repr(transparent)]
pub struct TrimOverrideEn(pub u32);
Trim

Tuple Fields

0: u32

Implementations

Source

impl TrimOverrideEn

pub const fn div_sel_override(&self) -> DivSelOverride

Override Enable for PLL Divider Value

pub const fn set_div_sel_override(&mut self, val: DivSelOverride)

Override Enable for PLL Divider Value

pub const fn tx_d_cal_override(&self) -> TxDCalOverride

Override Enable for HS TX Output Current Trim

pub const fn set_tx_d_cal_override(&mut self, val: TxDCalOverride)

Override Enable for HS TX Output Current Trim

pub const fn tx_cal45dp_override(&self) -> TxCal45dpOverride

Override Enable for USB_DP Series Termination Trim

pub const fn set_tx_cal45dp_override(&mut self, val: TxCal45dpOverride)

Override Enable for USB_DP Series Termination Trim

pub const fn tx_cal45dm_override(&self) -> TxCal45dmOverride

Override Enable for USB_DM Series Termination Trim

pub const fn set_tx_cal45dm_override(&mut self, val: TxCal45dmOverride)

Override Enable for USB_DM Series Termination Trim

pub const fn pll_ctrl0_div_sel(&self) -> u8

PLL Divider Value Configuration Bits from Outside USBPHY

pub const fn set_pll_ctrl0_div_sel(&mut self, val: u8)

PLL Divider Value Configuration Bits from Outside USBPHY

pub const fn usbphy_tx_d_cal(&self) -> UsbphyTxDCal

HS TX Output Current Trim Bits from Outside USBPHY

pub const fn set_usbphy_tx_d_cal(&mut self, val: UsbphyTxDCal)

HS TX Output Current Trim Bits from Outside USBPHY

pub const fn usbphy_tx_cal45dp(&self) -> u8

DP Series Termination Resistance Trim Bits from Outside USBPHY

pub const fn set_usbphy_tx_cal45dp(&mut self, val: u8)

DP Series Termination Resistance Trim Bits from Outside USBPHY

pub const fn usbphy_tx_cal45dn(&self) -> u8

DM Series Termination Resistance Trim Bits from Outside USBPHY

pub const fn set_usbphy_tx_cal45dn(&mut self, val: u8)

DM Series Termination Resistance Trim Bits from Outside USBPHY